# remirepo spec file for php-pecl-ip2location
#
# Copyright (c) 2017-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package       php-pecl-ip2location
%endif

%global pecl_name  ip2location
%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%if "%{php_version}" < "5.6"
%global ini_name  %{pecl_name}.ini
%else
%global ini_name   40-%{pecl_name}.ini
%endif

%global upstream_version 8.2.0
#global upstream_prever  RC1
%global libversion       8.4

Summary:        Get geo location information of an IP address
Name:           %{?scl_prefix}php-pecl-%{pecl_name}
License:        PHP-3.01
Version:        %{upstream_version}%{?upstream_prever:~%{upstream_prever}}
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{upstream_version}%{?upstream_prever}.tgz

BuildRequires:  make
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-devel
# ensure proper version is used
BuildRequires:  IP2Location-devel >= %{libversion}
Requires:       IP2Location-libs%{?_isa} >= %{libversion}

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}                = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}        = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})          = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}  = %{version}


%description
This PHP extension enables you to get the geo location information of
an IP address, such as country, region or state, city, latitude and
longitude, US ZIP code, time zone, Internet Service Provider (ISP) or
company name, domain name, net speed, area code, weather station code,
weather station name, mobile country code (MCC), mobile network code
(MNC) and carrier brand, elevation, and usage type.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{upstream_version}%{?upstream_prever} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -e '/README.TXT/s/role="doc"/role="test"/' \
    -e '/AGREEMENT.PDF/s/role="doc"/role="test"/' \
    -i package.xml

cd NTS
sed -e "s/\r//" -i LICENSE CREDITS *.md *.c *.h

# Check version
extver=$(sed -n '/#define PHP_IP2LOCATION_VERSION/{s/.* "//;s/".*$//;p}' php_ip2location.h)
if test "x${extver}" != "x%{upstream_version}%{?upstream_prever}"; then
   : Error: Upstream version is ${extver}, expecting %{upstream_version}%{?upstream_prever}.
   exit 1
fi
cd ..

%if %{with_zts}
cp -r NTS ZTS
%endif

cat <<EOF | tee %{ini_name}
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure --with-php-config=%{_bindir}/php-config
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure --with-php-config=%{_bindir}/zts-php-config
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make install -C NTS INSTALL_ROOT=%{buildroot}

install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install the ZTS stuff
%if %{with_zts}
make install -C ZTS INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
: simple NTS module load test
%{_bindir}/php --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: upstream test suite
cd NTS
TEST_PHP_EXECUTABLE=%{_bindir}/php \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{_bindir}/php -n run-tests.php --show-diff

%if %{with_zts}
: simple ZTS module load test
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

: upstream test suite
cd ../ZTS
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
NO_INTERACTION=1 \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php --show-diff
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%config(noreplace) %{php_inidir}/%{ini_name}

%{php_extdir}/%{pecl_name}.so
%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Jun 12 2023 Remi Collet <remi@remirepo.net> - 8.2.0-1
- update to 8.2.0

* Fri Jul 29 2022 Remi Collet <remi@remirepo.net> - 8.1.2-1
- update to 8.1.2

* Mon Sep  6 2021 Remi Collet <remi@remirepo.net> - 8.1.1-5
- F35 build

* Wed Sep 01 2021 Remi Collet <remi@remirepo.net> - 8.1.1-3
- rebuild for 8.1.0RC1

* Sat Nov 28 2020 Remi Collet <remi@remirepo.net> - 8.1.1-2
- rebuild against library 8.3.1 in Fedora/EPEL

* Fri Nov 20 2020 Remi Collet <remi@remirepo.net> - 8.1.1-1
- update to 8.1.1
- drop patch merged upstream

* Thu Nov 19 2020 Remi Collet <remi@remirepo.net> - 8.1.0-1
- update to 8.1.0
- drop all patches merged upstream

* Wed Nov 18 2020 Remi Collet <remi@remirepo.net> - 8.0.1-11
- add patch to improve configure output from
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/13
- add patch for ip2location_bin_version in 8.3.1 from
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/15

* Sat Oct 17 2020 Remi Collet <remi@remirepo.net> - 8.0.1-10
- rebuild against library 8.2.0 in Fedora/EPEL

* Tue Oct  6 2020 Remi Collet <remi@remirepo.net> - 8.0.1-9
- rebuild against library 8.1.3 in Fedora/EPEL

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 8.0.1-8
- add patches for library version 8.1.4 and for PHP 8 from
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/12

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 8.0.1-7
- rebuild for PHP 8.0.0RC1

* Fri Sep 25 2020 Remi Collet <remi@remirepo.net> - 8.0.1-6
- add patches for library version 8.1 and for PHP 8 from
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/8
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/9
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/10
  https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/11

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 8.0.1-5
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 8.0.1-4
- rebuild for 7.4.0beta1

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 8.0.1-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 8.0.1-2
- rebuld for 7.3.0alpha4 new ABI

* Wed Nov  8 2017 Remi Collet <remi@remirepo.net> - 8.0.1-1
- Update to 8.0.1 (no change)
- License is PHP

* Sun Nov  5 2017 Remi Collet <remi@remirepo.net> - 8.0.0-1
- initital RPM
- open https://github.com/chrislim2888/IP2Location-PECL-Extension/issues/6
  for LICENSE clarification
- open https://github.com/chrislim2888/IP2Location-PECL-Extension/pull/5
  for a minimal test suite
